@@ -4,6 +4,9 @@
 # Univention Management Console
 #  module: password reset service
 #
+# Like what you see? Join us!
+# https://www.univention.com/about-us/careers/vacancies/
+#
 # Copyright 2015-2022 Univention GmbH
 #
 # https://www.univention.de/
@@ -907,7 +910,7 @@ class Instance(Base):
 			txt = fp.read()
 		txt = txt.format(username=username)
 		msg = MIMENonMultipart('text', 'plain', charset='utf-8')
-		msg["Subject"] = "Account deletion"
+		msg["Subject"] = ucr.get("umc/self-service/account-deregistration/email/subject", "Account deletion")
 		msg["Date"] = formatdate(localtime=True)
 		msg["From"] = ucr.get("umc/self-service/account-deregistration/email/sender_address", "Password Reset Service <noreply@{}>".format(".".join([ucr["hostname"], ucr["domainname"]])))
 		msg["To"] = mail
@@ -1130,7 +1133,7 @@ class Instance(Base):
 			txt = fp.read()
 		txt = txt.format(username=username, old_email=old_email, new_email=new_email)
 		msg = MIMENonMultipart('text', 'plain', charset='utf-8')
-		msg["Subject"] = "Account recovery email changed"
+		msg["Subject"] = ucr.get("umc/self-service/email-change-notification/email/subject", "Account recovery email changed")
 		msg["Date"] = formatdate(localtime=True)
 		msg["From"] = ucr.get("umc/self-service/passwordreset/email/sender_address", "Password Reset Service <noreply@{}>".format(".".join([ucr["hostname"], ucr["domainname"]])))
 		msg["To"] = old_email
